pub fn compression_ratio(dim: usize, deltas: &[DeltaEntry]) -> f64Expand description
Compute the compression ratio: full_size / delta_size.
Returns how many times smaller the delta representation is.
pub fn compression_ratio(dim: usize, deltas: &[DeltaEntry]) -> f64Compute the compression ratio: full_size / delta_size.
Returns how many times smaller the delta representation is.